LessThan class

Defines an expression that is equal when the left is less than the right.

Inheritance
Available extensions

Constructors

LessThan(Operand left, Operand right)
const
LessThan.fieldValue(String fieldPath, dynamic input)

Properties

hashCode int
The hash code for this object.
no setterinherited
left Operand
finalinherited
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(Expression other) Expression

Available on Expression, provided by the ExpressionExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
or(Expression other) Expression

Available on Expression, provided by the ExpressionExtension extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited